pub enum PathElem {
Node(Node),
Edge(Edge),
}Expand description
One element of a Value::Path — a path is node, edge, node, edge, ..., node, alternating, as a single Vec, not two parallel node/edge
vecs (which would create an unenforced nodes.len() == edges.len() + 1 invariant across every place a path gets built or read).
Variants